-- Top Module
-- Designed by T.Iwata at DIGITALFILTER.COM 2006/05/15

library IEEE;
use IEEE.std_logic_1164.all;

entity CPLD_TOP is
	PORT	(
	CLK	: IN std_logic;
	RST_N	: IN std_logic;
	CAPTURE	: IN std_logic;
	DOWNLOAD	: IN std_logic;
	PACKET	: IN std_logic;
	STROBE	: IN std_logic;
	TRIGENB : IN std_logic;
	DUTDATA	: IN std_logic_vector(7 downto 0);
	REGCLK : IN std_logic;
	REGDATA : IN std_logic;
	REGLATCH : IN std_logic;
	READY : OUT std_logic;
	PICDATA	: OUT std_logic_vector(7 downto 0);
	SRAMADDR	: OUT std_logic_vector(11 downto 0);
	SRAMDATA	: INOUT std_logic_vector(7 downto 0);
	SRAMLE_N	: OUT std_logic;
	SRAMHE_N	: OUT std_logic;
	SRAMWR_N	: OUT std_logic;
	SRAMRD_N	: OUT std_logic;
	SRAMCS_N : OUT std_logic;
	GENOUT	: OUT std_logic_vector(7 downto 0) );
end CPLD_TOP ;

architecture structure of CPLD_TOP is

component SRAM_CTRL
	Port (
	CLK	: IN std_logic;
	RST_N	: IN std_logic;
	CAPTURE	: IN std_logic;
	DOWNLOAD	: IN std_logic;
	PACKET	: IN std_logic;
	STROBE	: IN std_logic;
	TRIGENB : IN std_logic;
	TRIGFOUND	: IN std_logic;
	DUTDATA	: IN std_logic_vector(7 downto 0);
	READY : OUT std_logic;
	PICDATA	: OUT std_logic_vector(7 downto 0);
	SRAMADDR	: OUT std_logic_vector(11 downto 0);
	SRAMDATA	: INOUT std_logic_vector(7 downto 0);
	SRAMLE_N	: OUT std_logic;
	SRAMHE_N	: OUT std_logic;
	SRAMWR_N	: OUT std_logic;
	SRAMRD_N	: OUT std_logic;
	SRAMCS_N	: OUT std_logic;
	DIVIDE	: IN std_logic_vector(1 downto 0);
	CAPENB : OUT std_logic );
end component;
    
component GEN_CTRL
	Port (
	 CLK : In std_logic; 
	RST_N : In std_logic; 
	GENPERIOD : In std_logic_vector(7 downto 0);
	GENTYPE : In std_logic;
	GENOUT : Out std_logic_vector(7 downto 0); 
   CAPENB	: IN std_logic ); 
end component;

component TRIG_CTRL
	Port (
	CLK : In std_logic; 
	RST_N : In std_logic; 
	DUTDATA : In std_logic_vector(7 downto 0);
	TRIGPAT : In std_logic_vector(7 downto 0);
	TRIGPOS : In std_logic_vector(1 downto 0);
	TRIGENB : In std_logic;
   TRIGFOUND : Out std_logic;
   CAPENB	: IN std_logic ); 
end component;
    
component REG_CTRL
	 Port (
	 REGCLK : In std_logic; 
	RST_N : In std_logic; 
	 REGDATA : In std_logic;
	 REGLATCH : In std_logic; 
	GENPERIOD : Out std_logic_vector(7 downto 0);
	 GENTYPE : Out std_logic;
	TRIGPOS : Out std_logic_vector(1 downto 0);
	TRIGPAT : Out std_logic_vector(7 downto 0);
	DIVIDE	: Out std_logic_vector(1 downto 0) );
end component;

 signal TRIGPAT_sig : std_logic_vector(7 downto 0);
 signal GENPERIOD_sig : std_logic_vector(7 downto 0);
 signal GENTYPE_sig : std_logic;
 signal TRIGPOS_sig : std_logic_vector(1 downto 0);
 signal TRIGFOUND_sig : std_logic;
 signal DIVIDE_sig : std_logic_vector(1 downto 0);
 signal CAPENB_sig : std_logic;
 
begin
  
SRAM_CTRL_1 : SRAM_CTRL port map (
   CLK		=> CLK,
   RST_N		=> RST_N,
   CAPTURE		=> CAPTURE,
   DOWNLOAD	=> DOWNLOAD,
   PACKET		=> PACKET,
   STROBE 		=> STROBE, 
   TRIGENB 		=> TRIGENB, 
   TRIGFOUND	=> TRIGFOUND_sig,
   DUTDATA		=> DUTDATA, 
   READY		=> READY, 
   PICDATA		=> PICDATA, 
   SRAMADDR	=> SRAMADDR, 
   SRAMDATA	=> SRAMDATA, 
   SRAMLE_N	=> SRAMLE_N,
   SRAMHE_N	=> SRAMHE_N,
   SRAMWR_N	=> SRAMWR_N, 
   SRAMRD_N	=> SRAMRD_N, 
   SRAMCS_N 	=> SRAMCS_N,
   DIVIDE => DIVIDE_sig, 
   CAPENB => CAPENB_sig );

GEN_CTRL_1 : GEN_CTRL port map (
   CLK 		=> CLK, 
   RST_N 		=> RST_N,
   GENPERIOD 	=> GENPERIOD_sig,
   GENTYPE		 => GENTYPE_sig, 
   GENOUT 		=> GENOUT,
   CAPENB => CAPENB_sig ); 

TRIG_CTRL_1 : TRIG_CTRL port map (
   CLK 		=> CLK,
   RST_N 		=> RST_N,
   DUTDATA		 => DUTDATA,
   TRIGPAT		 => TRIGPAT_sig,
   TRIGPOS		 => TRIGPOS_sig,
   TRIGENB		 => TRIGENB, 
   TRIGFOUND 	=> TRIGFOUND_sig,
   CAPENB => CAPENB_sig );

REG_CTRL_1 : REG_CTRL port map (
   REGCLK		 => REGCLK,
   RST_N 		=> RST_N, 
   REGDATA		 => REGDATA,
   REGLATCH	 => REGLATCH,
   GENTYPE		 => GENTYPE_sig, 
   GENPERIOD	 => GENPERIOD_sig, 
   TRIGPAT		 => TRIGPAT_sig, 
   TRIGPOS 		=> TRIGPOS_sig,
   DIVIDE => DIVIDE_sig );

end structure ;
