-- Generator Control
-- Designed by T.Iwata at DIGITALFILTER.COM 2006/05/15

LIBRARY ieee;
USE ieee.std_logic_1164.all;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

ENTITY GEN_CTRL IS
	PORT	(
		CLK	: IN std_logic;
		RST_N	: IN std_logic;
		GENPERIOD	: IN std_logic_vector(7 downto 0);
		GENTYPE : IN std_logic;
		GENOUT	: OUT std_logic_vector(7 downto 0);
      CAPENB	: IN std_logic ); 
END GEN_CTRL;

ARCHITECTURE structure OF GEN_CTRL IS

	signal FreeCount : std_logic_vector(15 downto 0);
	signal genpulse : std_logic_vector(7 downto 0);

BEGIN
-------------------------------------------------------------- 
gen_FreeCount : process( RST_N, CLK )  
begin 
   if( RST_N = '0' ) then
		FreeCount <= (others => '0');
   elsif( CLK'event and CLK = '1' ) then
      if(CAPENB = '1') then 
         if(GENTYPE = '0' and FreeCount = GENPERIOD) then 
	         FreeCount <= (others => '0');
         else 
            FreeCount <= FreeCount + 1;
         end if;
      end if;
   end if;  
end process;

-------------------------------------------------------------- 
   genpulse(7) <= '1' when (FreeCount(15 downto 0) < GENPERIOD) else '0';
   genpulse(6) <= '1' when (FreeCount(14 downto 0) < GENPERIOD) else '0';
   genpulse(5) <= '1' when (FreeCount(13 downto 0) < GENPERIOD) else '0';
   genpulse(4) <= '1' when (FreeCount(12 downto 0) < GENPERIOD) else '0';
   genpulse(3) <= '1' when (FreeCount(11 downto 0) < GENPERIOD) else '0';
   genpulse(2) <= '1' when (FreeCount(10 downto 0) < GENPERIOD) else '0';
   genpulse(1) <= '1' when (FreeCount(9 downto 0) < GENPERIOD) else '0';
   genpulse(0) <= '1' when (FreeCount(8 downto 0) < GENPERIOD) else '0';

-------------------------------------------------------------- 
   GENOUT <= FreeCount(7 downto 0) when GENTYPE = '0' else genpulse;
	
END structure;
