-- Trigger Control
-- Designed by T.Iwata at DIGITALFILTER.COM 2006/05/15

library IEEE;
  use IEEE.std_logic_1164.all;
  use IEEE.std_logic_arith.all;
  use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity TRIG_CTRL is
   Port (
          RST_N : In std_logic; 
          CLK : In std_logic; 
          DUTDATA : In std_logic_vector(7 downto 0);
          TRIGENB : In std_logic;
          TRIGPAT : In std_logic_vector(7 downto 0);
          TRIGPOS : In std_logic_vector(1 downto 0);
          TRIGFOUND : Out std_logic;
          CAPENB	: IN std_logic ); 
end TRIG_CTRL;

architecture STRUCTURE of TRIG_CTRL is

   signal LatencyCount : std_logic_vector(12 downto 0);
   signal data_match : std_logic;
   
begin -- architecture TRIG_CTRL
-------------------------------------------------------------------
gen_data_match : process( RST_N, CLK ) 
begin
	if(RST_N = '0') then
		data_match <= '0';
	elsif( CLK'event and CLK = '1' ) then
		if(DUTDATA = TRIGPAT and TRIGENB = '1') then 
			data_match <= '1';
		else 
			data_match <= '0';
		end if;
	end if;
end process;

-------------------------------------------------------------- 
gen_LatencyCount : process( RST_N, CLK )  
begin 
	if( RST_N = '0' ) then
		LatencyCount <= (others => '1');
	elsif( CLK'event and CLK = '1' ) then
		if(CAPENB = '1') then 
			if(data_match = '1' and LatencyCount(12) = '1') then 
				LatencyCount <= (others => '0');
			elsif(LatencyCount(12) = '0') then 
				LatencyCount <= LatencyCount + 1;
			end if; 
		end if;
	end if;  
end process;

-------------------------------------------------------------- 
   TRIGFOUND <= '1' when (LatencyCount = 4093 and TRIGPOS = "00") 
		or (LatencyCount = 4000 and TRIGPOS = "01")
		or (LatencyCount = 3000 and TRIGPOS = "10")
		or (LatencyCount = 2000 and TRIGPOS = "11") else '0';
						   
end; -- architecture TRIG_CTRL
